@@ -4,7 +4,28 @@ from requests.exceptions import RequestException
 from QuickStart_Rhy import headers
 
 
-def check_one_page(url):
+def is_mac(addr: str):
+    """
+    检查addr是否为mac地址
+
+    Check whether addr is a mac address
+
+    :param addr: string like '80:8f:1d:e2:f2:f5'
+    :return: bool
+    """
+    part = addr.split(':')
+    if len(part) != 6:
+        return False
+    for i in part:
+        if len(i) != 2:
+            return False
+        for j in i:
+            if j not in '0123456789abcdefABCDEF':
+                return False
+    return True
+
+
+def check_one_page(url: str):
     """
     检查url是否可访问
 
@@ -20,7 +41,7 @@ def check_one_page(url):
         return False
 
 
-def formatUrl(try_url):
+def formatUrl(try_url: str):
     """
     为url添加https或http使其能被访问
 
@@ -58,7 +79,7 @@ def get_ip():
         return socket.gethostbyname(socket.gethostname())
 
 
-def size_format(sz, align=False):
+def size_format(sz: int, align: bool = False):
     """
     格式化文件大小显示
 
@@ -94,24 +115,29 @@ def get_ip_info():
         return None
 
 
-def get_fileinfo(url):
+def get_fileinfo(url: str, proxy: str = ''):
     """
     获取待下载的文件信息
 
     Gets information about the file to be downloaded
 
     :param url: 文件url
+    :param proxy: 代理
     :return: 真实url，文件名，http头部信息
     """
     import re
     import os
+    proxies = {
+        'http': 'http://'+proxy,
+        'https': 'https://'+proxy
+    } if proxy else {}
     try:
-        res = requests.head(url, headers=headers)
-    except:
+        res = requests.head(url, headers=headers, proxies=proxies)
+    except Exception as e:
         return False, False, False
     while res.status_code == 302 or res.status_code == 301:
         url = res.headers['Location']
-        res = requests.head(url, headers=headers)
+        res = requests.head(url, headers=headers, proxies=proxies)
     if 'Content-Disposition' in res.headers:
         try:
             filename = re.findall('filename=(.*?);', res.headers['Content-Disposition'])[0]
