@@ -67,13 +67,15 @@ def net_menu():
     print(color_rep("""Net Tools help:
     qs -http [ip] [-bind url] :-> start a multithread ftp server
     qs -netinfo [<domains>..] :-> get url's info which in clipboard or params 
-    qs -dl [urls]             :-> download file from url(in clipboard)
+    qs -dl [urls] [-help]     :-> download file from url(in clipboard)
+    qs -wifi                  :-> connect wifi
     qs -upload                :-> upload your pypi library
     qs -upgrade               :-> update qs""")) \
         if user_lang != 'zh' else print(color_rep("""网络工具:
     qs -http [ip] [-bind url] :-> 在当前路径下开启多线程http服务
     qs -netinfo [<domains>..] :-> 获取命令参数或剪切板中链接或ip的信息 
     qs -dl [urls]             :-> 从命令参数或剪切板中链接下载文件
+    qs -wifi                  :-> 连接wifi
     qs -upload                :-> 上传你的pypi仓库
     qs -upgrade               :-> 更新qs"""))
 
@@ -96,7 +98,8 @@ def api_menu():
     qs -bcv <url/video code>  :-> get Bilibili video cover image with <url>
     qs -gbc <garbage...>      :-> check Chinese garbage classification
     qs -svi <url>             :-> get short video info
-    qs -svd <url>             :-> download short video info as mp4"""))\
+    qs -svd <url>             :-> download short video info as mp4
+    qs -acg [save]            :-> get an acg image link (or save)"""))\
         if user_lang != 'zh' else print(color_rep("""API工具:
     qs -trans [content]       :-> 翻译命令参数或剪切板中的内容
     qs -rmbg <img>            :-> 移除图片背景
@@ -113,20 +116,25 @@ def api_menu():
     qs -bcv <url/video code>  :-> 获取B站视频、直播封面图片
     qs -gbc <garbage...>      :-> 查询垃圾分类
     qs -svi <url>             :-> 获取多平台短视频信息
-    qs -svd <url>             :-> 下载多平台短视频为mp4"""))
+    qs -svd <url>             :-> 下载多平台短视频为mp4
+    qs -acg [save]            :-> 获取一张acg图片链接（或保存）"""))
 
 
 def image_menu():
     """图像处理类菜单 | Image Deal Menu"""
     print(color_rep("""Image Tools help:
     qs -stbg pic to [from]    :-> color replace for picture
+    qs -icat <img>            :-> preview image on terminal
     qs -v2gif path [sz] [fps] :-> generate gif from video
     qs -v2mp4 <video>         :-> format video to mp4
+    qs -v2mp3 <video>         :-> extract audio from video and save in MP3
     qs -rmaudio <video>       :-> remove audio in video (return mp4 only)""")) \
         if user_lang != 'zh' else print(color_rep("""图像处理:
     qs -stbg pic to [from]    :-> 替换图片颜色（from默认为透明）
+    qs -icat <img>            :-> 在终端预览图片
     qs -v2gif path [sz] [fps] :-> 将视频导出为gif
     qs -v2mp4 <video>         :-> 将视频导出为mp4
+    qs -v2mp3 <video>         :-> 提取视频音频为mp3
     qs -rmaudio <video>       :-> 删除mp4文件音频"""))
 
 
@@ -164,6 +172,7 @@ net_funcs = {
     'self': 'nettools',
     '-http': 'http',
     '-dl': 'download',
+    '-wifi': 'wifi',
     '-upgrade': 'upgrade',
     '-upload': 'upload_pypi',
     '-netinfo': 'netinfo'
@@ -186,13 +195,16 @@ api_funcs = {
     '-bcv': 'bili_cover',
     '-gbc': 'gbc',
     '-svi': 'short_video_info',
-    '-svd': 'short_video_dl'
+    '-svd': 'short_video_dl',
+    '-acg': 'acg'
 }
 
 image_funcs = {
     'self': 'imagedeal',
     '-stbg': 'set_img_background',
+    '-icat': 'icat',
     '-v2gif': 'v2gif',
     '-rmaudio': 'remove_audio',
-    '-v2mp4': 'v2mp4'
+    '-v2mp4': 'v2mp4',
+    '-v2mp3': 'v2mp3'
 }
