@@ -52,7 +52,7 @@ def v2gif():
         exit(0)
     else:
         video_2_gif(video, sz, fps) if sz and fps else video_2_gif(video, sz) \
-            if sz else video_2_gif(video, fps) if fps else video_2_gif(video)
+            if sz else video_2_gif(video, fps=fps) if fps else video_2_gif(video)
 
 
 def remove_audio():
@@ -61,7 +61,7 @@ def remove_audio():
     try:
         video = sys.argv[2]
     except IndexError:
-        exit('Usage: qs -remove_audio *.mp4')
+        exit('Usage: qs -rmaudio *.mp4')
     else:
         rm_audio(video)
 
@@ -75,3 +75,28 @@ def v2mp4():
         exit('Usage: qs -v2mp4 <video>')
     else:
         tomp4(video)
+
+
+def v2mp3():
+    """提取视频音频为mp3 | Extract the audio from the video and save it in MP3 format"""
+    from QuickStart_Rhy.ImageTools.VideoTools import video_2_mp3
+    try:
+        video = sys.argv[2]
+    except IndexError:
+        exit('Usage: qs -v2mp3 <video>')
+    else:
+        video_2_mp3(video)
+
+
+def icat():
+    try:
+        path = sys.argv[2]
+        is_url = '-u' in sys.argv
+        if not os.path.exists(path) and not is_url:
+            print('No such file:', path)
+            raise FileNotFoundError
+    except:
+        exit('Usage: qs -icat <img/url>')
+    else:
+        from QuickStart_Rhy.ImageTools.ImagePreview import image_preview
+        image_preview(open(path)) if not is_url else image_preview(path, is_url)
